@@ -270,6 +270,10 @@ class EnvironmentService:
         check()
         return make_call(environment_pb2_grpc.EnvironmentServiceStub(channel).GetEnvironment, request)
 
+    def IsIdAvailable(self, request):
+        check()
+        return make_call(environment_pb2_grpc.EnvironmentServiceStub(channel).IsIdAvailable, request)
+
     def ListRegions(self, request):
         check()
         return make_call(environment_pb2_grpc.EnvironmentServiceStub(channel).ListRegions, request)
@@ -280,6 +284,12 @@ class EnvironmentService:
     def GetEnvironmentResponse(self, **kwargs):
         return environment_pb2.GetEnvironmentResponse(**kwargs)
 
+    def IsIdAvailableRequest(self, **kwargs):
+        return environment_pb2.IsIdAvailableRequest(**kwargs)
+
+    def IsIdAvailableResponse(self, **kwargs):
+        return environment_pb2.IsIdAvailableResponse(**kwargs)
+
     def ListRegionsRequest(self, **kwargs):
         return environment_pb2.ListRegionsRequest(**kwargs)
 
